<?php
/*
Plugin Name: Restrict Content Pro - Affiliates / Pro / Enterprise
Plugin URL: http://pippinsplugins.com/rcp-affiliates-pro
Description: Restrict Content Pro Integration for Affiliates, Affiliates Pro and Affiliates Enterprise
Version: 1.1
Author: Pippin Williamson
Author URI: http://pippinsplugins.com
Contributors: mordauk, itthinx
*/

// ***************************************************************************
//
// Set your referral rate below if you are using the Affiliates plugin.
// This rate is NOT used with Affiliates Pro or Affiliates Enterprise.
// The default rate is 0.1 granting 10% commissions.
//
// ***************************************************************************

define( 'RCP_REFERRAL_RATE', 0.1 );

// ***************************************************************************
// The line above must look like this:
//
//     define( 'RCP_REFERRAL_RATE', 0.1 );
//
// You can change 0.1 to something else, for example 0.25 to grant 25%
// commissions.
//
// Please DO NOT EDIT anything below (developers only).
//
// ***************************************************************************

function rcp_award_commission( $payment_id, $payment_data, $amount ) {
	global $wpdb;
	if ( function_exists( '_affiliates_get_tablename' ) ) {
		$referrals_table = _affiliates_get_tablename( 'referrals' );
		if ( $referral_id = $wpdb->get_var( $wpdb->prepare( "SELECT referral_id FROM $referrals_table WHERE reference = %s", $payment_data['subscription_key'] ) ) ) {
			if ( class_exists( 'Affiliates_Referral_WordPress' ) ) {
				$r = new Affiliates_Referral_WordPress( $referral_id );
				$r->update( array( 'status' => AFFILIATES_REFERRAL_STATUS_ACCEPTED ) );
			} else if ( function_exists( 'affiliates_suggest_referral' ) ) {
				affiliates_update_referral( $referral_id, array( 'status' => AFFILIATES_REFERRAL_STATUS_ACCEPTED ) );
			}
		}
	}
}
add_action( 'rcp_insert_payment', 'rcp_award_commission', 10, 3 );

function aff_rcp_subscription_data( $subscription_data ) {

	global $rcp_options;

	$user_link = '<a href="' . admin_url( 'admin.php?page=rcp-members&view_member=' . $subscription_data['user_id'] ) . '">' . __( 'View User', 'rcp' ) . '</a>';

	$amount = floatval( $subscription_data['price'] );
	if ( $subscription_data['auto_renew'] ) {
		$amount += floatval( $subscription_data['fee'] );
	}

	$data = array(
		'subscription_key' => array(
			'title'  => __( 'Subscription Key', 'rcp' ),
			'domain' => 'rcp',
			'value'  => esc_sql( $subscription_data['key'] )
		),
		'subscription_total' => array(
			'title'  => __( 'Total', 'rcp' ),
			'domain' =>  'rcp',
			'value'  => esc_sql( $amount )
		),
		'referred_user' => array(
			'title'  => __( 'Referred User', 'rcp' ),
			'domain' => 'rcp',
			'value'  => esc_sql( $user_link )
		)
	);

	$description = sprintf( __('Subscription %s #%s', 'rcp'), $subscription_data['subscription_name'], $subscription_data['key'] );

	if( class_exists( 'Affiliates_Referral_WordPress' ) ) {
		$r = new Affiliates_Referral_WordPress();
		$r->evaluate( 0, $description, $data, $amount, null, $rcp_options['currency'], AFFILIATES_REFERRAL_STATUS_PENDING, 'subscription', $subscription_data['key'] );
	} else if ( function_exists( 'affiliates_suggest_referral' ) ) {
		$amount = round( floatval( RCP_REFERRAL_RATE ) * floatval( $amount ), AFFILIATES_REFERRAL_AMOUNT_DECIMALS );
		affiliates_suggest_referral( 0, $description, $data, $amount, $rcp_options['currency'], AFFILIATES_REFERRAL_STATUS_PENDING, 'subscription', $subscription_data['key'] );
	}
	return $subscription_data;
}
add_filter( 'rcp_subscription_data', 'aff_rcp_subscription_data' );
